# 
# Copyright (C) 1996-2003 LAAS/CNRS 
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 
#    - Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above
#      copyright notice, this list of conditions and the following
#      disclaimer in the documentation and/or other materials provided
#      with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
# 
# $LAAS$
#----------------------------------------------------------------------
#
# Sample code to create a second display window
#
proc aux_window {} {

    if ![winfo exists .aux] {
	toplevel .aux
	togl .aux.ogl -width 320 -height 200 -rgba true -double true \
	    -depth true -ident aux -sharelist main
	pack .aux.ogl  -side left -padx 3 -pady 3 -fill both -expand t 
	
	addWindow .aux.ogl

	.aux.ogl setObs -dist 4 -elev 90 -azi 0 -x 0 -y 0 -z 0 
	.aux.ogl setObs -ortho
	.aux.ogl redraw
	setLights
    }
}

#----------------------------------------------------------------------

## 
## Update a camera mounted on a robot 
##
proc update_robot_window { name index op } {
    upvar $name pos

    # Check the window existence
    set w .on$index.ogl
    if ![winfo exists $w] {
	# nothing to do if inexistent
	return {}
    }
    # Get the robot's position
    # XXX only the case of a robots with planar coordinates is handled 
    set x [ lindex $pos($index) 0]
    set y [ lindex $pos($index) 1]
    set theta [lindex $pos($index) 2]
    # set the observer's position
    $w setObs -dist 1 -elev 20 -azi [expr 90-$theta] -x $x -y $y -z 1.3
    # ready to redraw
    $w redraw
}

#----------------------------------------------------------------------

##
## Create a camera mounted on a robot
##
proc robot_window {r} {
    global pos

    set w .on$r

    if ![winfo exists $w] {
	toplevel $w
	wm title $w "Camera on $r"

	togl $w.ogl -width 640 -height 480 -rgba true -double true \
	    -depth true -ident $r -sharelist main
	pack $w.ogl  -side left -padx 3 -pady 3 -fill both -expand t 
	
	addWindow $w.ogl
	update_robot_window pos $r r

	setLights
    }
    # Update view whenever the robot moves
    trace variable pos r update_robot_window 
}

