/*
 * Copyright (C) 1996-2001 LAAS/CNRS 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
#include "config.h"
__RCSID("$LAAS$");

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tcl.h>

/**
 ** Affichage de la carte de segkit
 **/
int
segkitMapCallBack(ClientData clientData, Tcl_Interp *interp,
		  int argc, Tcl_Obj *const argv[])
{
    FILE *f;
    char *fileName, *var;
    int i, nsg;
    Tcl_Obj *buf[4], *p;
    double x1, y1, x2, y2;

    if (argc != 3) {
	Tcl_SetObjResult(interp, Tcl_NewStringObj("wrong # args: should be "
						  "\"segkitMap var file\"", -1));
	return TCL_ERROR;
    }
    
    fileName = Tcl_GetStringFromObj(argv[2], NULL);
    if ((f = fopen(fileName, "r")) == NULL) {
	Tcl_SetResult(interp, "can't open file", TCL_STATIC);
	return TCL_ERROR;

    }
    fscanf(f,"%ld",&nsg);
    fscanf(f,"%*lf %*lf %*lf %*lf %*lf %*lf %*c \n");
    fscanf(f,"%*lf %*lf %*lf %*lf\n");
    for (i = 0; i < nsg; i++) {
	fscanf(f, "%lf ",&x1);
	fscanf(f, "%lf \n",&y1);
	fscanf(f, "%lf ",&x2);
	fscanf(f, "%lf ",&y2);

	buf[0] = Tcl_NewDoubleObj(x1);
	buf[1] = Tcl_NewDoubleObj(y1);
	buf[2] = Tcl_NewDoubleObj(x2);
	buf[3] = Tcl_NewDoubleObj(y2);
	p = Tcl_NewListObj(4, buf);
	
	Tcl_ObjSetVar2(interp, argv[1], NULL, p, 
		   TCL_APPEND_VALUE | TCL_LIST_ELEMENT | TCL_GLOBAL_ONLY);
	fscanf(f, "%*lf %*lf %*lf\n");
	fscanf(f, "%*lf %*lf\n");
	fscanf(f, "%*lf %*lf %*lf \n");
	fscanf(f, "%*c %*c \n");
    }
    fclose(f);
    return TCL_OK;
}

int
Segkit_Init(Tcl_Interp *interp)
{
    int code;
 
    code = Tcl_PkgProvide(interp, "Gdhe::segkit", "2.0");
    if (code != TCL_OK) {
        return code;
    }
 
    Tcl_CreateObjCommand(interp, "segkitMap", segkitMapCallBack, NULL, NULL);
    return TCL_OK;
}
